env = ARGV[2]
attr_to_set = ARGV[3]
attr_val = ARGV[4]
tier = ARGV[5]

puts env
puts attr_to_set
puts attr_val
search(:node,"chef_environment:#{env} AND qubole_tier:#{tier}")do |n|
  puts n.name
  n.set[attr_to_set] = attr_val
  n.save
end

exit 0
